// Include DTSource.h if you want to include all the headers.

#include "DTArguments.h"
#include "DTSaveError.h"

#include "DTDataFile.h"
#include "DTMesh1DGrid.h"
#include "DTPlot1D.h"

#include <math.h>

DTPlot1D Computation(DTMesh1DGrid Grid);

int main(int argc,const char *argv[])
{
    DTSetArguments(argc,argv);

    DTDataFile inputFile("Input.dtbin",DTFile::ReadOnly);
    // Read in the input variables.
    DTMesh1DGrid Grid;
    Read(inputFile,"Grid",Grid);

    // The computation.
    DTPlot1D computed;
    clock_t t_before = clock();
    computed = Computation(Grid);
    clock_t t_after = clock();
    double exec_time = double(t_after-t_before)/double(CLOCKS_PER_SEC);

    // Write the output.
    DTDataFile outputFile("Output.dtbin",DTFile::NewReadWrite);

    // Output from computation
    Write(outputFile,"Var",computed);
    outputFile.Save("Plot1D","Seq_Var");

    // The execution time.
    outputFile.Save(exec_time,"ExecutionTime");
    outputFile.Save("Real Number","Seq_ExecutionTime");

    // The errors.
    DTSaveError(outputFile,"ExecutionErrors");
    outputFile.Save("StringList","Seq_ExecutionErrors");

    return 0;
}

DTPlot1D Computation(DTMesh1DGrid Grid)
{
    DTPlot1D toReturn;

    // Extract information from the Grid variable
    int m = Grid.m();
    double dx = Grid.h();
    double x0 = Grid.Origin();
    
    DTMutableDoubleArray xNumbers(m); // Allocates the array, does not set the values.
    DTMutableDoubleArray yNumbers(m);
    int i;
    double x;
    
    for (i=0;i<m;i++) {
        x = x0 + i*dx;
        xNumbers(i) = x;
        yNumbers(i) = sin(x);
    }
    
    // Now create the return variable
    toReturn = DTPlot1D(xNumbers,yNumbers);
    
    return toReturn;
}
